==> imwiki-0.6.2.tar.gz: imwiki-0.6.2/imLib/imFormatter/HTMLFormatter.py <==
# -*- coding: utf8 -*-
import imLib.utils as utils
import imLib.macroProcessor
import imLib.Request as Request
import imLib.Page as Page 

class HTMLFormatter:
	def __init__(self):
		pass
	def heading(self, title, level):
		return '<h%s><a id="%s" name="%s">%s</a></h%s>' % (level, title, title, title, level)
	def pre(self, text):
		return '<pre>%s</pre>' % text
	def tt(self, text):
		return '<tt>%s</tt>' % tt
	def strong(self, text):
		return '<strong>%s</strong>' % text
	def em(self, text):
		return '<em>%s</em>' % text
	def strongEm(self, text):
		return '<strong><em>%s</em></strong>' % text
	def strike(self, text):
		return '<strike>%s</strike>' % text
	def underline(self, text):
		return '<u>%s</u>' % text
	def superscript(self, text):
		return '<sup>%s</sup>' % text
	def subscript(self, text):
		return '<sub>%s</sub>' % text
	def horizon(self, lines):
		# level = len(lines)  두깨를 선택하게 할까?
		return '<hr />'
	def internalLink(self, categoryPath, pageName, isAbsolutePath):
		request = Request.Request()
		if isAbsolutePath:
			page = Page.getPage(categoryPath, pageName)
		else:
			categoryPath = utils.joinPath(request.categoryPath, categoryPath) 
			page = Page.travelAlongRails(categoryPath, pageName)
		return page and page.toLink() or utils.makeLink(categoryPath, pageName, klass='notExist')
	def externalLink(self, url, linkName=''):
		return '<a href="%s">%s</a>' % (url, linkName or url)
	def table(self, rowList):
		table = []
		table.append('<table>')
		for row in rowList:
			L = []
			for cell in row:
				if type(cell) == type(()):
					teul = '<td align="%s">%s</td>'
				else:
					teul = '<td>%s</td>'
				L.append(teul % cell)
			curRow = ''.join(L)
			table.append("<tr>%s</tr>" % curRow)
		table.append('</table>')
		return ''.join(table)

	def indent(self, parsedList): # FIXME indent와 list는 너무 똑같다.
		L = []
		numOfUnclosed = 0
		for depth, contents in parsedList:
			if depth >= 0: tag = '<div class="imIndent">' 
			else: tag = '</div>'
			numOfUnclosed = numOfUnclosed + depth
			L.append(tag * abs(depth) + contents)
		L.append('</div>' * numOfUnclosed)
		return ''.join(L)

	def List(self, parsedList): # FIXME refactoring
		L = []
		openedTypeList = []
		for depth, listType, contents in parsedList:
			if listType: tagType = 'ol'
			else: tagType = 'ul'

			if depth >= 0: 
				tag = '<%s%s>' % (tagType, listType and ' type="%s"' % listType or '')

				openedTypeList.extend([tagType]*depth)
				tag = tag * abs(depth)
			else: 
				tag = ''	
				for i in range(abs(depth)):
					tag = tag + '</%s>' % openedTypeList.pop()
			L.append(tag  + contents)
		tag = ''
		for tagType in openedTypeList[::-1]:
			tag = tag + '</%s>' % tagType
		L.append(tag)
		return ''.join(L)

	def listitem(self, text):
		return '<li>%s</li>' % text
	def macro(self, text):
		macroName, args = imLib.macroProcessor.extractArgs(text)
		return imLib.macroProcessor.runMacro(macroName, args)

==> imwiki-0.6.3.tar.gz: imwiki-0.6.3/imLib/imFormatter/HTMLFormatter.py <==
# -*- coding: utf8 -*-
import imLib.utils as utils
import imLib.macroProcessor
import imLib.Request as Request
import imLib.Page as Page 
import imLib.config as config

class HTMLFormatter:
	def __init__(self):
		pass
	def heading(self, title, level):
		return '<h%s><a id="%s" name="%s">%s</a></h%s>' % (level, title, title, title, level)
	def pre(self, text):
		return '<pre>%s</pre>' % text
	def tt(self, text):
		return '<tt>%s</tt>' % text
	def strong(self, text):
		return '<strong>%s</strong>' % text
	def em(self, text):
		return '<em>%s</em>' % text
	def strongEm(self, text):
		return '<strong><em>%s</em></strong>' % text
	def strike(self, text):
		return '<strike>%s</strike>' % text
	def underline(self, text):
		return '<u>%s</u>' % text
	def superscript(self, text):
		return '<sup>%s</sup>' % text
	def subscript(self, text):
		return '<sub>%s</sub>' % text
	def blockquote(self, text):
		return '<blockquote>%s</blockquote>' % text
	def q(self, text):
		return '<q>%s</q>' % text
	def horizon(self, lines):
		# level = len(lines)  두깨를 선택하게 할까?
		return '<hr />'
	def internalLink(self, categoryPath, pageName, isAbsolutePath):
		request = Request.Request()
		if isAbsolutePath:
			page = Page.getPage(categoryPath, pageName)
		else:
			categoryPath = utils.joinPath(request.categoryPath, categoryPath) 
			page = Page.travelAlongRails(categoryPath, pageName)
		return page and page.toLink() or utils.makeLink(categoryPath, pageName, klass='notExist')
	def externalLink(self, url, linkName=''):
		return '<a href="%s">%s</a>' % (url, linkName or url)
	def table(self, rowList):
		table = []
		table.append('<table>')
		for row in rowList:
			L = []
			for cell in row:
				if type(cell) == type(()):
					teul = '<td align="%s">%s</td>'
				else:
					teul = '<td>%s</td>'
				L.append(teul % cell)
			curRow = ''.join(L)
			table.append("<tr>%s</tr>" % curRow)
		table.append('</table>')
		return ''.join(table)

	def indent(self, parsedList): # FIXME indent와 list는 너무 똑같다.
		L = []
		numOfUnclosed = 0
		for depth, contents in parsedList:
			if depth >= 0: tag = '<div class="imIndent">' 
			else: tag = '</div>'
			numOfUnclosed = numOfUnclosed + depth
			L.append(tag * abs(depth) + contents)
		L.append('</div>' * numOfUnclosed)
		return ''.join(L)

	def List(self, parsedList): # FIXME refactoring
		L = []
		openedTypeList = []
		for depth, listType, contents in parsedList:
			if listType: tagType = 'ol'
			else: tagType = 'ul'

			if depth >= 0: 
				tag = '<%s%s>' % (tagType, listType and ' type="%s"' % listType or '')

				openedTypeList.extend([tagType]*depth)
				tag = tag * abs(depth)
			else: 
				tag = ''	
				for i in range(abs(depth)):
					tag = tag + '</%s>' % openedTypeList.pop()
			L.append(tag  + contents)
		tag = ''
		for tagType in openedTypeList[::-1]:
			tag = tag + '</%s>' % tagType
		L.append(tag)
		return ''.join(L)

	def listitem(self, text):
		return '<li>%s</li>' % text
	def macro(self, text):
		macroName, args = imLib.macroProcessor.extractArgs(text)
		return imLib.macroProcessor.runMacro(macroName, args)

	def smiley(self, text):
		return '<img src="%s/img/%s" alt="%s" />' % (config.urlPrefix, config.smileyDict[text], text)
